@@ -5,22 +5,17 @@ use std::task::{Context, Poll};
 use futures_util::future::poll_fn;
 
 use crate::driver::Driver;
-use crate::local_executor::LocalExecutor;
+use crate::local_executor;
 use crate::waker_fn::waker_fn;
 
 pub struct Runtime {
-    local_executor: LocalExecutor,
     driver: Driver,
 }
 
 impl Runtime {
     pub fn new() -> io::Result<Runtime> {
-        let local_executor = LocalExecutor::new();
-        let driver = Driver::new()?;
-
         Ok(Runtime {
-            local_executor,
-            driver,
+            driver: Driver::new()?,
         })
     }
 
@@ -30,17 +25,15 @@ impl Runtime {
     {
         pin_mut!(future);
         self.driver.with(|| {
-            self.local_executor.with(|| {
-                block_on(poll_fn(|cx| loop {
-                    if let Poll::Ready(output) = future.as_mut().poll(cx) {
-                        return Poll::Ready(output);
-                    }
-                    if self.local_executor.tick() {
-                        return Poll::Pending;
-                    }
-                    self.driver.wait().expect("driver wait error");
-                }))
-            })
+            block_on(poll_fn(|cx| loop {
+                if let Poll::Ready(output) = future.as_mut().poll(cx) {
+                    return Poll::Ready(output);
+                }
+                if local_executor::tick() {
+                    return Poll::Pending;
+                }
+                self.driver.wait().expect("driver wait error");
+            }))
         })
     }
 }
@@ -48,9 +41,7 @@ impl Runtime {
 /// Runs a future to completion on the current thread.
 fn block_on<T>(future: impl Future<Output = T>) -> T {
     pin_mut!(future);
-
     let waker = waker_fn(|| {});
-
     let cx = &mut Context::from_waker(&waker);
     loop {
         match future.as_mut().poll(cx) {
